<?php
/*
Plugin Name: EasyCPMods Toolbox
Plugin URI: http://www.easycpmods.com
Description: EasyCPMods Toolbox is a free plugin for those who use EasyCPMods plugins. It allows grouping plugins into one group and will check for EasyCPMods plugin updates.
Author: EasyCPMods
Version: 2.1.1
Author URI: http://www.easycpmods.com
Text Domain: ecpm-etb
*/

define('ECPM_ETB_NAME', 'EasyCPMods Toolbox');
define('ECPM_ETB', 'ecpm-etb');
define('ECPM_ETB_VERSION', '2.1.1');
define('ECPM_ETB_UPLOAD_FOLDER', 'ecpm_etb_plugin_logos');
define('ECPM_ETB_SITE_URL', 'https://easycpmods.com/');
//define('ECPM_ETB_API_URL', 'http://192.168.2.15/ecpmdev4/ecpm-check/');
define('ECPM_ETB_API_URL', ECPM_ETB_SITE_URL.'ecpm-check/');

register_activation_hook( __FILE__, 'ecpm_etb_activate');
register_deactivation_hook( __FILE__, 'ecpm_etb_deactivate');
//register_uninstall_hook( __FILE__, 'ecpm_etb_uninstall');

add_action('admin_enqueue_scripts', 'ecpm_etb_enqueue_scripts');
add_action('ecpm_toolbox_event', 'ecpm_etb_toolbox_event');

//add_action('admin_init', 'ecpm_etb_settings_init');
add_action('admin_menu', 'ecpm_etb_options_page');

/**
 * custom option and settings
 */
/*
function ecpm_etb_settings_init() {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if ($ecpm_etb_settings['group_settings'] == 'on') {
    //register_setting( 'ecpm-menu', 'ecpm_etb_options' );
  }  
}
*/

/**
 * top level menu
 */
function ecpm_etb_options_page() {
  $update_icon = '';
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if (is_array($ecpm_etb_settings) && array_key_exists('group_settings', $ecpm_etb_settings) && $ecpm_etb_settings['group_settings'] == 'on') {
    if ($ecpm_etb_settings['update_available'] === true)
      $update_icon = '<span class="etb-update" title="'.__('Update available', ECPM_ETB).'"></span>';
    
    add_menu_page( 'EasyCPMods', 'EasyCPMods'.$update_icon, 'manage_options', 'ecpm-menu', 'ecpm_etb_settings_page_callback' );
    add_submenu_page( 'ecpm-menu', ECPM_ETB_NAME, ECPM_ETB_NAME, 'manage_options', 'ecpm_etb_settings_page', 'ecpm_etb_settings_page_callback' );
  } else {
    add_options_page(ECPM_ETB_NAME, ECPM_ETB_NAME, 'manage_options', 'ecpm_etb_settings_page', 'ecpm_etb_settings_page_callback');
  }  
}

function ecpm_etb_activate() {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if ( empty($ecpm_etb_settings) ) {
    $ecpm_etb_settings = array(
      'group_settings' => 'on',
      'check_update' => 'weekly',
      'api_key' => '',
      'remote_plugin_data' => array(),
      'update_available' => false,
      'show_count' => '4',
      'key_status' => '',
      'key_error' => '',
    );
    update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
  }
}

function ecpm_etb_deactivate(){
  wp_clear_scheduled_hook('ecpm_etb_toolbox_event');
}

function ecpm_etb_plugins_loaded() {
  $dir = dirname(plugin_basename(__FILE__)).DIRECTORY_SEPARATOR.'languages'.DIRECTORY_SEPARATOR;
    load_plugin_textdomain(ECPM_ETB, false, $dir);
}

function ecpm_etb_enqueue_scripts() {
  wp_enqueue_style('ecpm_etb_style', plugins_url('ecpm-etb.css', __FILE__), array(), null);
}

function ecpm_etb_is_cp4() {
  if ( defined("CP_VERSION") )
    $cp_version = CP_VERSION;
  else   
    $cp_version = get_option('cp_version');
    
  if (version_compare($cp_version, '4.0.0') >= 0) {
    return true;
  }
  
  return false;
}

function ecpm_etb_toolbox_event($manual_call = false){
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if (empty($ecpm_etb_settings['api_key']))
    return;
  
  $api_key = $ecpm_etb_settings['api_key'];
  
  $plugin_list = ecpm_etb_check_plugins();
  $installed_plugins = implode('*', array_merge($plugin_list['active'], $plugin_list['installed']));

  ecpm_etb_update_plugin_data($manual_call, $installed_plugins);
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
}

function ecpm_etb_update_plugin_data($manual_call, $installed_plugins = '') {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  $ecpm_etb_settings['update_available'] = false;
  $response = wp_remote_get( ECPM_ETB_API_URL.'updatedata?key='.$ecpm_etb_settings['api_key'].'&installed='.$installed_plugins );
//echo "<br>".$response;
  if( is_array($response) ) {
    $response_data = json_decode(wp_remote_retrieve_body($response), true);

    if (is_array($response_data)) {
      if (isset($response_data['error'])) {
        if ($manual_call) 
          echo scb_admin_notice( $response_data['error'], 'error' );
          
        if ( in_array($response_data['error_type'], array('2', '4')) ) {
          if ($response_data['error_type'] == '4')
            $ecpm_etb_settings['key_status'] = 'disabled';
          else  
            $ecpm_etb_settings['key_status'] = false;
            
          $ecpm_etb_settings['key_error'] = $response_data['error'];
        }  
      } else {
        $ecpm_etb_settings['remote_plugin_data'] = array();

        foreach ($response_data as $key => $plugin_data) {
          $ecpm_etb_settings['remote_plugin_data'][$key] = array(
            'plugin_name' => $plugin_data['name'],
            'plugin_description' => stripslashes($plugin_data['description']),
            'plugin_version' => $plugin_data['version'],
            'plugin_logo' => NULL,
            'plugin_url' => $plugin_data['url'],
            'plugin_path' => $plugin_data['path'],
            'plugin_file' => $plugin_data['file'],
            'plugin_cp3' => $plugin_data['cp3'],
            'plugin_cp4' => $plugin_data['cp4'],
            );

            if (array_key_exists('logo', $plugin_data) && $plugin_data['logo'] != '') {
              $image_file = ecpm_etb_save_photo($plugin_data['image'], $plugin_data['logo']);
              $ecpm_etb_settings['remote_plugin_data'][$key]['plugin_logo'] = $image_file;
            }

            $latest_version = ecpm_etb_check_latest($key, $ecpm_etb_settings);
            if ($latest_version['compatibility'] === true && $latest_version['status'] !== true && $latest_version['installed_version'] != '')
              $ecpm_etb_settings['update_available'] = true;  
        }

        $ecpm_etb_settings['key_status'] = true;
        $ecpm_etb_settings['key_error'] = '';    
      }  
    }  
  }

  update_option( 'ecpm_etb_settings', $ecpm_etb_settings );

//    return $ecpm_etb_settings;
}

function ecpm_etb_save_photo($fileContents, $isbn) {
  $target_dir = ecpm_etb_get_upload_folder();

  $newImg = imagecreatefromstring(base64_decode($fileContents));
  $isbn = str_replace('.png', '.jpg', $isbn);

  imagejpeg($newImg, $target_dir.$isbn, 100);

  return ecpm_etb_get_upload_folder(true).$isbn;
}

function ecpm_etb_get_upload_folder($return_url = false) {
  $target_dir = wp_upload_dir();

  if ($return_url)
    return $target_dir['baseurl'].'/'.ECPM_ETB_UPLOAD_FOLDER.'/';

  $folder_exists = ecpm_etb_create_upload_folder($target_dir);
  if ( $folder_exists) {
    $basedir = $target_dir['basedir'].'/'.ECPM_ETB_UPLOAD_FOLDER.'/';
    
    if ( !is_writable( $basedir ) )
      return false;
    else
      return $basedir;
  } else {  
    return false;
  }
}


function ecpm_etb_create_upload_folder($target_dir) {
  $work_dir = $target_dir['basedir'].'/'.ECPM_ETB_UPLOAD_FOLDER;
//echo $work_dir;
  if ( !file_exists( $work_dir ) ) {
    $folder_exists = wp_mkdir_p( $work_dir );
  }

  return true;
}


function ecpm_etb_read_plugin_data($plugin_code = '') {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  $plugins = array();

  $plugin_data = $ecpm_etb_settings['remote_plugin_data'];

  foreach ($plugin_data as $key => $plugin) {

    $plugins[ $key ] = array(
      'name' => $plugin['plugin_name'],
      'description' => $plugin['plugin_description'],
      'version' => $plugin['plugin_version'], 
      'logo' => $plugin['plugin_logo'], 
      'url' => $plugin['plugin_url'], 
      'path' => $plugin['plugin_path'], 
      'file' => $plugin['plugin_file'], 
      'cp3' => $plugin['plugin_cp3'],  
      'cp4' => $plugin['plugin_cp4'], 
    );
  }
    
  if ($plugin_code)
    return $plugins[$plugin_code];
  else  
    return $plugins;
}


function ecpm_etb_check_plugins(){
  $plugin_list = array(
    'active' => array(),
    'installed' => array(),
    'not_installed' => array(),
  );
  
  $plugins = ecpm_etb_read_plugin_data();
  
  foreach ($plugins as $key => $plugin){
    if ( is_plugin_active($plugin['path'].'/'.$plugin['file']) )
      $plugin_list['active'][] = $key;
    else {
      if ( file_exists(ABSPATH . 'wp-content/plugins/'.$plugin['path'].'/'.$plugin['file'] ) ) {
        $plugin_list['installed'][] = $key;
      } else {
        $plugin_list['not_installed'][] = $key;
      }
    }  
  }
    
  if (empty($plugin_list))
    return false;  
  else {
    return $plugin_list;
  }    
}

function ecpm_etb_check_latest($plugin_code, $ecpm_etb_settings){
  $ret_value = array('status' => false, 'installed_version' => '', 'version' => '', 'compatibility' => true);
  $plugin_etb_data = ecpm_etb_read_plugin_data($plugin_code);

  $my_file = untrailingslashit(ABSPATH . 'wp-content'.DIRECTORY_SEPARATOR.'plugins'.DIRECTORY_SEPARATOR.$plugin_etb_data['path'].DIRECTORY_SEPARATOR.$plugin_etb_data['file']);
  
  if (file_exists( $my_file) ) {
    $plugin_file = ABSPATH . 'wp-content/plugins/' .$plugin_etb_data['path'].DIRECTORY_SEPARATOR.$plugin_etb_data['file'];
    $plugin_data = get_plugin_data( $plugin_file );
    $ret_value['installed_version'] = $plugin_data['Version'];
  }
  
  if (isset($ecpm_etb_settings['remote_plugin_data'])) {
    foreach ($ecpm_etb_settings['remote_plugin_data'] as $key => $plugin) {
      if ($key == $plugin_code ) {
        break;
      }
    }
  } else {
    return $ret_value;
  } 
  
  if (!isset($plugin))
    return $ret_value;

  if ( (ecpm_etb_is_cp4() && $plugin_etb_data['cp4']) || (!ecpm_etb_is_cp4() && $plugin_etb_data['cp3']) )
    $ret_value['compatibility'] = true;
  else
    $ret_value['compatibility'] = false;

  if ( !isset($plugin_data) || $plugin_data['Version'] != $plugin['plugin_version'])
    $ret_value['status'] = false; 
  else {
    $ret_value['status'] = true;
  }

  $ret_value['version'] = $plugin['plugin_version'];

  return $ret_value;   
}

function ecpm_etb_plugin_table() {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');

  $plugin_data = $ecpm_etb_settings['remote_plugin_data'];
  $plugin_key = array_rand($plugin_data);
  $feat_plugin =  $plugin_data[$plugin_key];
?>
  <table cellspacing="0" cellpadding="4">
    <tr>
      <td align="center">Random <a href="<?= ECPM_ETB_SITE_URL;?>" target="_blank">EasyCPMods</a> plugin:</td>
    </tr>
    <tr>
      <td align="center" style="text-color:grey;"><h2><?=$feat_plugin['plugin_name'];?></h2></td>
    </tr>  
    <tr>
      <td><a href="<?= ECPM_ETB_SITE_URL.$feat_plugin['plugin_url'];?>" target="_blank"><img src="<?= esc_url($feat_plugin['plugin_logo']);?>" style="border:1px solid;" width="100%" title="<?=esc_html($feat_plugin['plugin_name']);?>" alt="<?=esc_html($feat_plugin['plugin_name']);?>"></a></td>
    </tr>
    <tr>
      <td><?=stripslashes($feat_plugin['plugin_description']);?></td>
    </tr>
    <tr><td></td></tr>
    <tr>
      <td colspan="2" align="right"><a href="<?= ECPM_ETB_SITE_URL;?>" target="_blank">EasyCPMods</a></td>  
    </tr>
  </table>  
  <?php
}

function ecpm_etb_show_plugins($type, $ecpm_etb_settings, $plugin_list, $all_plugins) {
  $title_array = array(
    'active' => __('Currently active EasyCPMods plugins', ECPM_ETB),
    'installed' => __('Not active EasyCPMods plugins', ECPM_ETB),    
    'not_installed' => __('Other EasyCPMods plugins you can install', ECPM_ETB),    
  );
  ?>
  <tr>
    <td colspan="3">
      <h3><?= $title_array[$type]; ?></h3>
      <table cellspacing="0" cellpadding="10">
        <tr>
        <?php 
        $hor_counter = 0;
        if (!empty($plugin_list)) {
          foreach ($all_plugins as $key => $plugin) {
            if (!in_array($key, $plugin_list[$type] ) )
              continue;

            $latest_version = ecpm_etb_check_latest($key, $ecpm_etb_settings);

            $gray_class = '';
            if ($latest_version['compatibility'] == false ) {
              $gray_class = "etb-grayout";
              $plugin_status = __('Not compatible with your version of Classipress', ECPM_ETB);
            } else {
              if ($latest_version['status'] === true)
                $plugin_status = __('You have the latest version', ECPM_ETB);
              else  
                $plugin_status = sprintf( __('Please install the latest version: <strong>%s</strong>', ECPM_ETB), $latest_version['version']);
            }

            ?>
            <td>
              <table class="<?=$gray_class;?>" border="0" cellpadding="10" cellspacing="1" style="width:298px">
                <tbody>
                  <tr>
                  <?php
                  if ($type == 'not_installed')
                    $update_style = 'etb-not-installed';
                  elseif ($latest_version['status'] === true) 
                    $update_style = 'etb-updated';
                  else
                    $update_style = 'etb-not-updated';
                  ?>
                    <td class="etb-main-table <?=$update_style;?>">
                      <table border="0" cellpadding="2" cellspacing="0" class="etb-inner-table">
                        <tbody>
                          <tr>
                            <th class="etb-inner-cell">
                              <?php
                              if (in_array($key, $plugin_list['active'])) {
                                echo '<h2><strong><a href="?page=ecpm_'.$key.'_settings_page">'. esc_html($plugin['name']).'</a></strong></h2>';
                              } else {
                                echo '<h2><strong>'.esc_html($plugin['name']).'</strong></h2>';
                              }
                              ?>
                            </th>
                          </tr>
                          <tr>
                            <td class="etb-inner-cell">
                              <a href="<?= ECPM_ETB_SITE_URL. esc_html($plugin['url']);?>/" target="_blank"><img src="<?= esc_url($plugin['logo']);?>" border="0" width="100%" title="<?= esc_html(stripslashes($plugin['description']));?>" alt="<?= esc_html($plugin['name']);?>"></a>
                            </td>
                          </tr>
                          <?php
                          if ($type != 'not_installed') {
                          ?>
                          <tr>
                            <td class="etb-inner-cell"><em><?= sprintf( __('Installed version: <strong>%s</strong>', ECPM_ETB), $latest_version['installed_version']);?></em></td>
                          </tr>
                          <?php
                          }
                          ?>
                          <tr>
                            <td class="etb-inner-cell"><strong><?= $plugin_status;?></strong></td>
                          </tr>
                        </tbody>
                      </table>
                    </td>
                  </tr>
                </tbody>
              </table>
            </td>
            
          <?php
            $hor_counter++;
            if ($hor_counter % $ecpm_etb_settings['show_count'] == 0)
              echo '</tr><tr>';
          }
          }
        ?>
        </tr>
        <tr><td colspan="<?=$ecpm_etb_settings['show_count'];?>"><hr></td></tr>
      </table>
    </td>
  </tr>
          
<?php
}

function ecpm_etb_settings_page_callback() {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
    
  if ( current_user_can( 'manage_options' ) ) {
// manual update
    if( isset( $_POST['ecpm_etb_submit_check'] ) ) {
      ecpm_etb_toolbox_event(true);
      
      $ecpm_etb_settings = get_option('ecpm_etb_settings');
      echo scb_admin_notice( __( 'Update complete.', APP_TD ), 'updated' );

// new key
    } elseif( isset( $_POST['ecpm_etb_submit_api'] ) ) {
      $response = wp_remote_get( ECPM_ETB_API_URL.'newkey?url='.get_site_url() );
  
      if( is_array($response) ) {
        $received_data = json_decode(wp_remote_retrieve_body($response), true);

        if (isset($received_data['error'])) {
          $ecpm_etb_settings['key_status'] = false;
          $ecpm_etb_settings['key_error'] = $received_data['error'];
          echo scb_admin_notice( $received_data['error'], 'error' );
        } else {
          $ecpm_etb_settings['api_key'] = $received_data['api_key'];
          $ecpm_etb_settings['key_status'] = true;
          $ecpm_etb_settings['key_error'] = '';
        }
        update_option( 'ecpm_etb_settings', $ecpm_etb_settings );  
      }
// check key    
    } elseif (isset($_POST['ecpm_etb_submit_checkkey'] ) ) {
      $response = wp_remote_get( ECPM_ETB_API_URL.'checkkey?key='.$ecpm_etb_settings['api_key'] );
  
      if( is_array($response) ) {
        $received_data = json_decode(wp_remote_retrieve_body($response), true);

        if (isset($received_data['key_status']) && $received_data['key_status'] == true ) {
          $ecpm_etb_settings['key_status'] = true;
          $ecpm_etb_settings['key_error'] = '';
          echo scb_admin_notice( __( 'You API key is OK.', ECPM_ETB ), 'updated' );
        } elseif (isset($received_data['error'])) {
            if ($received_data['error_type'] == '4')
              $ecpm_etb_settings['key_status'] = 'disabled';
            else  
              $ecpm_etb_settings['key_status'] = false;
              
          $ecpm_etb_settings['key_error'] = $received_data['error'];
          echo scb_admin_notice( $received_data['error'], 'error' );
        } 
        update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
      }
//      
    } elseif( isset( $_POST['ecpm_etb_submit'] ) ) {
      $update_freq_values = array('daily', 'weekly', 'never');
      
      if (isset($_POST[ 'ecpm_group_settings' ]) && $_POST[ 'ecpm_group_settings' ] == 'on')
        $ecpm_etb_settings['group_settings'] = $_POST[ 'ecpm_group_settings' ];
      else
        $ecpm_etb_settings['group_settings'] = '';
      
      if ( in_array($_POST[ 'ecpm_etb_check_update' ], $update_freq_values) ) { 
        $ecpm_etb_settings['check_update'] = sanitize_text_field($_POST[ 'ecpm_etb_check_update' ]);
        
        wp_clear_scheduled_hook('ecpm_toolbox_event');
        
        if ($ecpm_etb_settings['check_update'] != 'never')
          wp_schedule_event( current_time( 'timestamp' ), $ecpm_etb_settings['check_update'], 'ecpm_toolbox_event');  
      
        
      }
      
      if ( is_numeric(intval( $_POST[ 'ecpm_etb_show_count' ] )) ) {
        $ecpm_etb_settings['show_count'] = $_POST[ 'ecpm_etb_show_count' ];
      }
        
      update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
      
      echo scb_admin_notice( __( 'Settings saved.', APP_TD ), 'updated' );

    }
  }   
  
  $key_status = $ecpm_etb_settings['key_status'];
  $plugin_list = ecpm_etb_check_plugins();
  $all_plugins = ecpm_etb_read_plugin_data();
  ?>
  
    <div id="fassetting">
        <div class="wrap">
            <h1><?= _e('EasyCPMods Toolbox Settings', ECPM_ETB); ?></h1>
      <?php
      echo "<i>Plugin version: <u>".ECPM_ETB_VERSION."</u>";
      echo "<br>Plugin language file: <u>ecpm-etb-".get_locale().".mo</u></i>";
      ?>
          <hr>
        <table width="800px" cellspacing="0" cellpadding="8" border="0">  
          <tr>
            <td width="2px" class="etb-key-status-<?= ($key_status === true ? 'ok':'notok');?>">
              
            </td>
            <th align="left">
              <label for="ecpm_api_key"><?= _e('EasyCPMods update API key', ECPM_ETB); ?></label>
            </th>
            <td align="right">
              <Input disabled type='text' size='20' Name ='ecpm_api_key' value='<?= esc_html($ecpm_etb_settings['api_key']);?>'>
            </td>
            <td align="left">
              <?php
              if ($key_status !== true) {
                if ($key_status != 'disabled') {
              ?>    
                <form id='etbkeyform' method="post" action="">
                  <input type="submit" id="ecpm_etb_submit_api" name="ecpm_etb_submit_api" class="button-primary" value="<?php _e('Get your free API key', ECPM_ETB); ?>" />
                </form>  
                <?php 
                } else {
                  echo $ecpm_etb_settings['key_error'];
                ?>  
                  <form id='etbkeycheckform' method="post" action="">
                    <input type="submit" id="ecpm_etb_submit_checkkey" name="ecpm_etb_submit_checkkey" class="button-primary" value="<?php _e('Check your key', ECPM_ETB); ?>" />
                  </form>
                <?php
                }
              } else {
              ?>  
                <form id='etbkeycheckform' method="post" action="">
                  <input type="submit" id="ecpm_etb_submit_checkkey" name="ecpm_etb_submit_checkkey" class="button-primary" value="<?php _e('Check your key', ECPM_ETB); ?>" />
                </form>
              <?php
              }  
              ?>
            </td>
          </tr>
        </table>
      <hr>
      <?php
      if (isset($ecpm_etb_settings['api_key']) && $key_status === true) {
      ?>
        <table width="100%" cellspacing="0" cellpadding="8" border="0">  
          <form id='etbsettingform' method="post" action="">
            <tr>
              <th align="left">
                  <label for="ecpm_group_settings"><?= _e('Group all EasyCPMods plugins in one settings group', ECPM_ETB); ?></label>
              </th>
              <td>
                <Input type='checkbox' id='ecpm_group_settings' Name='ecpm_group_settings' <?= ($ecpm_etb_settings['group_settings'] == 'on' ? 'checked':'') ;?> >
              </td>
              <td>        
                <span class="description"><?php _e( 'Easy CP Mods plugins will not appear on Settings group but in a separate group called EasyCPMods' , ECPM_ETB ); ?></span>
                </td>
            </tr>
          
            <tr>
                <th align="left">
                    <label for="ecpm_etb_check_update"><?= _e('Check for EasyCPMods plugin updates', ECPM_ETB); ?></label>
                </th>
                <td align="left">
                    <select id='ecpm_etb_check_update' name="ecpm_etb_check_update">
                <option value="never" <?= ($ecpm_etb_settings['check_update'] == 'never' ? 'selected':'') ;?>><?php _e('Never', ECPM_ETB);?></option>
                <option value="daily" <?= ($ecpm_etb_settings['check_update'] == 'daily' ? 'selected':'') ;?>><?php _e('Daily', ECPM_ETB);?></option>
                <option value="weekly" <?= ($ecpm_etb_settings['check_update'] == 'weekly' ? 'selected':'') ;?>><?php _e('Weekly', ECPM_ETB);?></option>
              </select>
            </td>
            <td>  
              <span class="description"><?php _e( 'Specify frequency for checking EasyCPMods plugin updates' , ECPM_ETB ); ?></span>
                </td>
            </tr>
          
            <tr>
                <th align="left">
                    <label for="ecpm_etb_show_count"><?= _e('Number of plugin icons per line', ECPM_ETB); ?></label>
                </th>
                <td align="left">
                    <select id='ecpm_etb_show_count' name="ecpm_etb_show_count">
                <?php
                for ($i=2; $i<=6; $i++) {
                ?>
                <option value="<?= $i;?>" <?= ($ecpm_etb_settings['show_count'] == $i ? 'selected':'') ;?>><?= $i;?></option>
                <?php
                }
                ?>
              </select>
            </td>
            <td>  
              <span class="description"><?php _e( 'How many icons should be shown in one line' , ECPM_ETB ); ?></span>
                </td>
            </tr>
          
          <tr>
            <td colspan="3"> 
                <p class="submit">
                <input type="submit" id="ecpm_etb_submit" name="ecpm_etb_submit" class="button-primary" value="<?php _e('Save settings', ECPM_ETB); ?>" />
                </p>
            </td>
          </tr>
          </form>

          <tr><td colspan="3"><hr></td></tr>
          <tr>      
            <td colspan="3">
            <form id='etbcheckform' method="post" action="">
              <p>       
                <input type="submit" id="ecpm_etb_submit_check" name="ecpm_etb_submit_check" class="button-primary" value="<?php _e('Check for updates now', ECPM_ETB); ?>" />
              </p>  
            </form>
            </td>
          </tr>
      
          <?php
          ecpm_etb_show_plugins('active', $ecpm_etb_settings, $plugin_list, $all_plugins);
          ecpm_etb_show_plugins('installed', $ecpm_etb_settings, $plugin_list, $all_plugins);
          ecpm_etb_show_plugins('not_installed', $ecpm_etb_settings, $plugin_list, $all_plugins);
          ?>
        </table>
      <?php
      } 
      ?>  
        </div>
    </div>
<?php
}
?>